aboutsummaryrefslogtreecommitdiff
path: root/libbutl/filesystem.cxx
diff options
context:
space:
mode:
authorBoris Kolpackov <boris@codesynthesis.com>2023-06-22 11:16:21 +0200
committerBoris Kolpackov <boris@codesynthesis.com>2023-06-22 11:16:21 +0200
commitc3bb3da52c81abcde83cb72e90b1b61f0627f580 (patch)
tree178104e4a54e6adf54bb6643000474d83dca2d44 /libbutl/filesystem.cxx
parentd58bb311ba5b981132f7b666a8ec0ecfeec6fd75 (diff)
Half Windows sleep times, use exponential backoff in fdselect()
Diffstat (limited to 'libbutl/filesystem.cxx')
-rw-r--r--libbutl/filesystem.cxx10
1 files changed, 5 insertions, 5 deletions
diff --git a/libbutl/filesystem.cxx b/libbutl/filesystem.cxx
index 07d0590..28a0de8 100644
--- a/libbutl/filesystem.cxx
+++ b/libbutl/filesystem.cxx
@@ -1142,12 +1142,12 @@ namespace butl
// failure (see mventry() for details). If that's the case, we will keep
// trying to move the file for two seconds.
//
- for (size_t i (0); i < 21; ++i)
+ for (size_t i (0); i < 41; ++i)
{
// Sleep 100 milliseconds before the removal retry.
//
if (i != 0)
- Sleep (100);
+ Sleep (50);
ur = _unlink (f);
@@ -1792,12 +1792,12 @@ namespace butl
// fdopen().
//
DWORD ec;
- for (size_t i (0); i < 21; ++i)
+ for (size_t i (0); i < 41; ++i)
{
// Sleep 100 milliseconds before the move retry.
//
if (i != 0)
- Sleep (100);
+ Sleep (50);
if (MoveFileExA (f, t, mfl))
return;
@@ -1142,12 +1142,12 @@ namespace butl
{
- // Sleep 100 milliseconds before the removal retry.
+ // Sleep 50 milliseconds before the removal retry.
//
if (i != 0)